"""Commands and control for the Onkyo eISCP interface.
"""

__author__ = 'Michael Elsdoerfer <michael@elsdoerfer.com>'

from core import eISCP
